==> nextcloud-21.0.0p0.tgz: nextcloud/apps/systemtags/l10n/mk.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "Името на ознаката е празна",
    "Update" : "Ажурирај",
    "Create" : "Креирај",
    "Select tag…" : "Избери ознака...",
    "System tag %1$s added by the system" : "Системска ознака %1$s е додадена во системот",
    "Added system tag {systemtag}" : "Додадена системска ознака {systemtag}",
    "Added system tag %1$s" : "Додадена системска ознака %1$s",
    "%1$s added system tag %2$s" : "%1$s додаде системска ознака %2$s",
    "{actor} added system tag {systemtag}" : "{actor} додаде системска ознака {systemtag}",
    "System tag %1$s removed by the system" : "Системска ознака %1$s е отстранета од системот",
    "Removed system tag {systemtag}" : "Отстранета системска ознака {systemtag}",
    "Removed system tag %1$s" : "Отстранета системска ознака %1$s",
    "%1$s removed system tag %2$s" : "%1$s отстрани системска ознака %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} отстрани системска ознака {systemtag}",
    "You created system tag %1$s" : "Креиравте системска ознака %1$s",
    "You created system tag {systemtag}" : "Креиравте системска ознака {systemtag}",
    "%1$s created system tag %2$s" : "%1$s креираше системска ознака %2$s",
    "{actor} created system tag {systemtag}" : "{actor} креираше системска ознака {systemtag}",
    "You deleted system tag %1$s" : "Избришавте системска ознака %1$s",
    "You deleted system tag {systemtag}" : "Избришавте системска ознака {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s избриша системска ознака %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} избриша системска ознака {systemtag}",
    "You updated system tag %2$s to %1$s" : "Ја ажуриравте системската ознака %2$s во %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Ја ажуриравте системската ознака {oldsystemtag} во {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ажурираше системска ознака %3$s во %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} ажурираше системска ознака {oldsystemtag} во {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Системска ознака %2$s е додадена на %1$s од системот",
    "System tag {systemtag} was added to {file} by the system" : "Системска ознака {systemtag} е додадена на {file} од системот",
    "You added system tag %2$s to %1$s" : "Додадовте системска ознака %2$s на %1$s",
    "You added system tag {systemtag} to {file}" : "Додадовте системска ознака {systemtag} на {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s додаде системска ознака %3$s на %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} додаде системска ознака {systemtag} на {file}",
    "System tag %2$s was removed from %1$s by the system" : "Системска ознака %2$s е отстранета од %1$s од системот",
    "System tag {systemtag} was removed from {file} by the system" : "Системска ознака {systemtag} е отстранета од {file} од системот",
    "You removed system tag %2$s from %1$s" : "Отстранивте системска ознака %2$s од %1$s",
    "You removed system tag {systemtag} from {file}" : "Отстранивте системска ознака {systemtag} од {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s отстрани системска ознака %3$s од %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} отстрани системска ознака {systemtag} од {file}",
    "%s (restricted)" : "%s (ограничена)",
    "%s (invisible)" : "%s (невидливо)",
    "<strong>System tags</strong> for a file have been modified" : "Изменета е <strong>Системска ознака</strong> за датотека",
    "Tags" : "Ознаки",
    "Collaborative tags" : "Колаборативна ознака",
    "Collaborative tagging functionality which shares tags among users." : "Колаборативна ознака е можност да се споделуваат ознаките со корисниците.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Колаборативна ознака е можност да се споделуваат ознаките со корисниците. Одлично за тимско работење.\n\t(Доколку користите провајдер со инсталирани повеќе инстанци, се препорачува да се оневозможи оваа апликацика бидејќи ознаките ќе бидат споделени.)",
    "Tagged files" : "Означени датотеки",
    "Select tags to filter by" : "Изберете филтер за ознака",
    "No tags found" : "Не се пронајдени ознаки",
    "Please select tags to filter by" : "Изберете ознака за да филтрирате",
    "No files found for the selected tags" : "Нема пронајдено датотеки за селектираната ознака",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Колаборативните ознаки се достапни за сите корисници. Ограничените ознаки се видливи за корисниците но неможат да ги додаваат. Невидливите ознаки се за внатрешна употреба, тоа значи дека корисниците неможат да ги видат или да ги додаваат.",
    "Select tag …" : "Избери ознака ...",
    "Create a new tag" : "Креирајте нова ознака",
    "Name" : "Име",
    "Public" : "Јавна",
    "Restricted" : "Ограничена",
    "Invisible" : "Невидливо",
    "Delete" : "Избриши",
    "Reset" : "Поништи",
    "No files in here" : "Тука нема датотеки",
    "No entries found in this folder" : "Нема ништо во оваа папка",
    "Size" : "Големина",
    "Modified" : "Променето"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-25.0.11.tgz: nextcloud/apps/systemtags/l10n/mk.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "Името на ознаката е празна",
    "Update" : "Ажурирај",
    "Create" : "Креирај",
    "Select tag …" : "Избери ознака ...",
    "System tag %1$s added by the system" : "Системска ознака %1$s е додадена во системот",
    "Added system tag {systemtag}" : "Додадена системска ознака {systemtag}",
    "Added system tag %1$s" : "Додадена системска ознака %1$s",
    "%1$s added system tag %2$s" : "%1$s додаде системска ознака %2$s",
    "{actor} added system tag {systemtag}" : "{actor} додаде системска ознака {systemtag}",
    "System tag %1$s removed by the system" : "Системска ознака %1$s е отстранета од системот",
    "Removed system tag {systemtag}" : "Отстранета системска ознака {systemtag}",
    "Removed system tag %1$s" : "Отстранета системска ознака %1$s",
    "%1$s removed system tag %2$s" : "%1$s отстрани системска ознака %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} отстрани системска ознака {systemtag}",
    "You created system tag %1$s" : "Креиравте системска ознака %1$s",
    "You created system tag {systemtag}" : "Креиравте системска ознака {systemtag}",
    "%1$s created system tag %2$s" : "%1$s креираше системска ознака %2$s",
    "{actor} created system tag {systemtag}" : "{actor} креираше системска ознака {systemtag}",
    "You deleted system tag %1$s" : "Избришавте системска ознака %1$s",
    "You deleted system tag {systemtag}" : "Избришавте системска ознака {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s избриша системска ознака %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} избриша системска ознака {systemtag}",
    "You updated system tag %2$s to %1$s" : "Ја ажуриравте системската ознака %2$s во %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Ја ажуриравте системската ознака {oldsystemtag} во {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ажурираше системска ознака %3$s во %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} ажурираше системска ознака {oldsystemtag} во {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Системска ознака %2$s е додадена на %1$s од системот",
    "System tag {systemtag} was added to {file} by the system" : "Системска ознака {systemtag} е додадена на {file} од системот",
    "You added system tag %2$s to %1$s" : "Додадовте системска ознака %2$s на %1$s",
    "You added system tag {systemtag} to {file}" : "Додадовте системска ознака {systemtag} на {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s додаде системска ознака %3$s на %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} додаде системска ознака {systemtag} на {file}",
    "System tag %2$s was removed from %1$s by the system" : "Системска ознака %2$s е отстранета од %1$s од системот",
    "System tag {systemtag} was removed from {file} by the system" : "Системска ознака {systemtag} е отстранета од {file} од системот",
    "You removed system tag %2$s from %1$s" : "Отстранивте системска ознака %2$s од %1$s",
    "You removed system tag {systemtag} from {file}" : "Отстранивте системска ознака {systemtag} од {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s отстрани системска ознака %3$s од %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} отстрани системска ознака {systemtag} од {file}",
    "%s (restricted)" : "%s (ограничена)",
    "%s (invisible)" : "%s (невидливо)",
    "<strong>System tags</strong> for a file have been modified" : "Изменета е <strong>Системска ознака</strong> за датотека",
    "Tags" : "Ознаки",
    "Collaborative tags" : "Колаборативна ознака",
    "Collaborative tagging functionality which shares tags among users." : "Колаборативна ознака е можност да се споделуваат ознаките со корисниците.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Колаборативна ознака е можност да се споделуваат ознаките со корисниците. Одлично за тимско работење.\n\t(Доколку користите провајдер со инсталирани повеќе инстанци, се препорачува да се оневозможи оваа апликацика бидејќи ознаките ќе бидат споделени.)",
    "This file has the tag {tag}" : "Оваа датотека има ознака {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Оваа датотека има ознаки {firstTags} и {lastTag}",
    "Tagged files" : "Означени датотеки",
    "Select tags to filter by" : "Изберете филтер за ознака",
    "No tags found" : "Не се пронајдени ознаки",
    "Please select tags to filter by" : "Изберете ознака за да филтрирате",
    "No files found for the selected tags" : "Нема пронајдено датотеки за селектираната ознака",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Колаборативните ознаки се достапни за сите корисници. Ограничените ознаки се видливи за корисниците но неможат да ги додаваат. Невидливите ознаки се за внатрешна употреба, тоа значи дека корисниците неможат да ги видат или да ги додаваат.",
    "Create a new tag" : "Креирајте нова ознака",
    "Name" : "Име",
    "Public" : "Јавна",
    "Restricted" : "Ограничена",
    "Invisible" : "Невидливо",
    "Delete" : "Избриши",
    "Reset" : "Поништи",
    "No files in here" : "Тука нема датотеки",
    "No entries found in this folder" : "Нема ништо во оваа папка",
    "Size" : "Големина",
    "Modified" : "Променето"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
